summaryrefslogtreecommitdiffstats
path: root/Utilities
diff options
context:
space:
mode:
Diffstat (limited to 'Utilities')
-rw-r--r--Utilities/cmlibuv/include/uv.h9
-rw-r--r--Utilities/cmlibuv/src/unix/process.c1
-rw-r--r--Utilities/cmlibuv/src/win/process.c20
3 files changed, 19 insertions, 11 deletions
diff --git a/Utilities/cmlibuv/include/uv.h b/Utilities/cmlibuv/include/uv.h
index ffe34ec..42e3446 100644
--- a/Utilities/cmlibuv/include/uv.h
+++ b/Utilities/cmlibuv/include/uv.h
@@ -1080,7 +1080,14 @@ enum uv_process_flags {
* option is only meaningful on Windows systems. On Unix it is silently
* ignored.
*/
- UV_PROCESS_WINDOWS_HIDE_GUI = (1 << 6)
+ UV_PROCESS_WINDOWS_HIDE_GUI = (1 << 6),
+ /*
+ * On Windows, if the path to the program to execute, specified in
+ * uv_process_options_t's file field, has a directory component,
+ * search for the exact file name before trying variants with
+ * extensions like '.exe' or '.cmd'.
+ */
+ UV_PROCESS_WINDOWS_FILE_PATH_EXACT_NAME = (1 << 7)
};
/*
diff --git a/Utilities/cmlibuv/src/unix/process.c b/Utilities/cmlibuv/src/unix/process.c
index 30872cf..39ec451 100644
--- a/Utilities/cmlibuv/src/unix/process.c
+++ b/Utilities/cmlibuv/src/unix/process.c
@@ -1008,6 +1008,7 @@ int uv_spawn(uv_loop_t* loop,
assert(!(options->flags & ~(UV_PROCESS_DETACHED |
UV_PROCESS_SETGID |
UV_PROCESS_SETUID |
+ UV_PROCESS_WINDOWS_FILE_PATH_EXACT_NAME |
UV_PROCESS_WINDOWS_HIDE |
UV_PROCESS_WINDOWS_HIDE_CONSOLE |
UV_PROCESS_WINDOWS_HIDE_GUI |
diff --git a/Utilities/cmlibuv/src/win/process.c b/Utilities/cmlibuv/src/win/process.c
index 7df3540..11cf5b2 100644
--- a/Utilities/cmlibuv/src/win/process.c
+++ b/Utilities/cmlibuv/src/win/process.c
@@ -329,10 +329,9 @@ static WCHAR* path_search_walk_ext(const WCHAR *dir,
* - If there's really only a filename, check the current directory for file,
* then search all path directories.
*
* - If a full path is specified, search for the exact filename first.
*
* - If filename specified has *any* extension, search for the file with the
* specified extension first.
*
* - If the literal filename is not found in a directory, try *appending*
* (not replacing) .com first and then .exe.
@@ -358,7 +357,8 @@ static WCHAR* path_search_walk_ext(const WCHAR *dir,
*/
static WCHAR* search_path(const WCHAR *file,
WCHAR *cwd,
- const WCHAR *path) {
+ const WCHAR *path,
+ unsigned int flags) {
int file_has_dir;
WCHAR* result = NULL;
WCHAR *file_name_start;
@@ -394,14 +394,12 @@ static WCHAR* search_path(const WCHAR *file,
name_has_ext = (dot != NULL && dot[1] != L'\0');
if (file_has_dir) {
- /* The file has a path inside, don't use path
- * Try the exact filename first, and then try standard extensions
- */
+ /* The file has a path inside, don't use path */
result = path_search_walk_ext(
file, file_name_start - file,
file_name_start, file_len - (file_name_start - file),
cwd, cwd_len,
- 1);
+ name_has_ext || (flags & UV_PROCESS_WINDOWS_FILE_PATH_EXACT_NAME));
} else {
dir_end = path;
@@ -991,6 +989,7 @@ int uv_spawn(uv_loop_t* loop,
assert(!(options->flags & ~(UV_PROCESS_DETACHED |
UV_PROCESS_SETGID |
UV_PROCESS_SETUID |
+ UV_PROCESS_WINDOWS_FILE_PATH_EXACT_NAME |
UV_PROCESS_WINDOWS_HIDE |
UV_PROCESS_WINDOWS_HIDE_CONSOLE |
UV_PROCESS_WINDOWS_HIDE_GUI |
@@ -1070,7 +1069,8 @@ int uv_spawn(uv_loop_t* loop,
application_path = search_path(application,
cwd,
- path);
+ path,
+ options->flags);
if (application_path == NULL) {
/* Not found. */
err = ERROR_FILE_NOT_FOUND;
@@ -329,10 +329,9 @@ static WCHAR* path_search_walk_ext(const WCHAR *dir,
* then search all path directories.
*
- * - If a full path is specified, search for the exact filename first.
- *
- * - If filename specified has *any* extension, search for the file with the
- * specified extension first.
+ * - If filename specified has *any* extension, or already contains a path
+ * and the UV_PROCESS_WINDOWS_FILE_PATH_EXACT_NAME flag is specified,
+ * search for the file with the exact specified filename first.
*
* - If the literal filename is not found in a directory, try *appending*